#!/bin/bash

__CORE_PATTERN=""

function save_core_pattern {
    __CORE_PATTERN=$(< /proc/sys/kernel/core_pattern)
}

function exit_with_code {
    echo ${1}
    exit ${2}
}

function restore_core_pattern {
    echo ${__CORE_PATTERN} > /proc/sys/kernel/core_pattern
}

function endoftime {
    TIMEOUT=$((TIMEOUT-1))
    if [ $((TIMEOUT)) == 0 ]; then
        return 0
    fi
    return 1
}

function check {
    if [[ ${RESULT} =~ ${1} ]]; then
        return 0
    fi
    exit_with_code "FAIL: not found ${1} in ${RESULT}" ${FAIL_CODE}
}

function check_file_exists {
    if [ ! -f ${1} ]; then
        exit_with_code "FAIL: file not exists $1" ${FAIL_CODE}
    fi
}

function check_file_not_exists {
    if [ -f ${1} ]; then
        exit_with_code "FAIL: file exists $1" ${FAIL_CODE}
    fi
}

function check_zip_contains {
    zipfile=${1}
    pattern="$2"
    if ! unzip -qql "$zipfile" | grep -E "$pattern"; then
        exit_with_code "FAIL: zip file ${zipfile} does not contain ${pattern}" ${FAIL_CODE}
    fi
}

function tzplatform_var {
    VAL=`tzplatform-get ${1}`
    if [ $? == 0 ]; then
        echo $VAL | cut -d'=' -f2
        return 0
    fi
    return 1
}

function clean_crash_dump {

    killall crash-manager
    killall minicoredumper

    sleep 1

    if [ ! -d ${CRASH_DUMP_PATH} ]; then
        exit_with_code "${CRASH_DUMP_PATH} does not exist" ${FAIL_CODE}
    fi

    rm -rf ${CRASH_DUMP_PATH}/*
}

function clean_logdump {

    killall log_dump
    sleep 1

    if [ -d ${LOGDUMP_RESULT_PATH} ]; then
        rm -rf ${LOGDUMP_RESULT_PATH}/*
    fi
}

function clean_temp {

    if [ -d ${CRASH_TEMP_PATH} ]; then
        rm -rf ${CRASH_TEMP_PATH}/*
    fi
}

function wait_for_file {
    TIMEOUT=240
    while [ ! -f ${1} ];
    do
        if endoftime; then
            exit_with_code "FAIL: ${1} does not exist" ${FAIL_CODE}
        else
            sleep 1
        fi
    done
    return 0
}

function wait_for_app {
    TIMEOUT=240
    while true;
    do
        if ! pidof ${1} 1> /dev/null 2>&1; then
            break;
        fi
        if endoftime; then
            exit_with_code "FAIL: ${1} is still running" ${FAIL_CODE}
        else
            sleep 1
        fi
    done
    sleep 1
    return 0
}

function backup_file {
    cp ${1} ${1}.backup
}

function restore_file {
    mv ${1}.backup ${1}
}

function untar_file {
    pushd ${1}
    tar xf ${2}
    popd
}

function __export_vars__ {

    export CRASH_TEMP_PATH=`tzplatform_var TZ_SYS_CRASH_ROOT`/temp
    if [ "x${CRASH_TEMP_PATH}" = 'x/temp' ]; then
        exit_with_code "Couldn't get TZ_SYS_CRASH_ROOT" ${FAIL_CODE}
    fi

    export LOGDUMP_RESULT_PATH=`tzplatform_var TZ_SYS_CRASH_ROOT`/debug
    if [ "x${LOGDUMP_RESULT_PATH}" = 'x/debug' ]; then
        exit_with_code "Couldn't get TZ_SYS_CRASH_ROOT" ${FAIL_CODE}
    fi

    export CRASH_DUMP_PATH=`tzplatform_var TZ_SYS_CRASH`
    if [ -z ${CRASH_DUMP_PATH} ]; then
        exit_with_code "Couldn't get TZ_SYS_CRASH or TZ_SYS_CRASH is empty" ${FAIL_CODE}
    fi

    export SUCCESS_CODE=0
    export FAIL_CODE=1
    export SKIP_CODE=2
}

function is_emulator {
    [[ `uname -m` =~ 86$ ]]
}

__export_vars__
